#
# spec file for package fde-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fde-tools
Version:        0.6.9
Release:        1.1
Summary:        Tools required for Full Disk Encryption
License:        GPL-2.0-only
Group:          System/Boot
URL:            https://github.com/openSUSE/fde-tools
Source:         https://github.com/openSUSE/%{name}/releases/download/%{version}/%{name}-%{version}.tar.bz2
Source1:        fde-tools.service
Patch:          fde-tools-firstboot-alp-snapshot.patch
BuildRequires:  help2man
BuildRequires:  pkgconfig(libcryptsetup)
BuildRequires:  pkgconfig(libfido2)
Requires:       cryptsetup
Requires:       mokutil
Requires:       pcr-oracle >= 0.4.5
Requires:       util-linux-systemd
ExclusiveArch:  aarch64 s390x ppc64le x86_64 riscv64

%package -n fde-firstboot
Summary:        Full Disk Encryption for images
Group:          System/Boot
Requires:       fde-tools
Requires:       jeos-firstboot

%description
This package provides several components required to support Full Disk
Encryption.

%description -n fde-firstboot
This package contains the scripts necessary to plug Full Disk Encryption
into the JeOS Firstboot framework used for image based delivery of ALP.

%package bash-completion
Summary:        Bash completion for fde-tools
Group:          Productivity/File utilities
Requires:       bash-completion
Requires:       fde-tools
Supplements:    (fde-tools and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash shell completions for fde-tools

%prep
%autosetup -p1

%build
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_fillupdir}
mv %{buildroot}/etc/sysconfig/fde-tools %{buildroot}%{_fillupdir}/sysconfig.fde-tools

mkdir -p %{buildroot}%{_unitdir}
cp %{S:1} %{buildroot}%{_unitdir}/fde-tpm-enroll.service

%pre
%service_add_pre fde-tpm-enroll.service

%post
%service_add_post fde-tpm-enroll.service
%fillup_and_insserv

%preun
%service_del_preun fde-tpm-enroll.service

%postun
%service_del_postun fde-tpm-enroll.service

%files
%{_sbindir}/fdectl
%{_sbindir}/fde-token
%{_sbindir}/fdectl-grub-tpm2
%dir /etc/fde
%{_fillupdir}/sysconfig.*
%{_datadir}/fde
%{_unitdir}/fde-tpm-enroll.service
%{_mandir}/man8/fdectl.8.gz
%dir %{_libdir}/cryptsetup/
%{_libdir}/cryptsetup/libcryptsetup-token-*.so

%files bash-completion
%{_datadir}/bash-completion/completions/fdectl

%files -n fde-firstboot
%dir %{_datadir}/jeos-firstboot
%dir %{_datadir}/jeos-firstboot/modules
%{_datadir}/jeos-firstboot/modules/fde

%changelog
* Tue Aug 29 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.9
  + Redirect the firstboot messages to journald instead of a
    standalone log file (bsc#1214581)
  + Update /boot/grub2/grub.cfg at the end of firstboot to reflect
    the LUKS key change
  + Update the version automatically
  + Add 'cryptsetup' to 'make dist'
  + Fix the version in fde.sh
- Update the download URL
* Thu Aug 24 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.8
  + Improve the LUKS partition detection to support LUKS over LVM
- Remove openssl and tpm2-0-tss-devel from BuildRequires since all
  TPM related programs are already in pcr-oracle
- Add util-linux-systemd to Requires for 'lsblk'
* Fri Aug 18 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.7
  + Check failure of authorized policy creation
  + Additional check for recovery password
- Drop upstreamed patch
  + fde-tools-handle-authorized-policy-failure.patch
* Thu Jul 27 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-handle-authorized-policy-failure.patch handle the
  failure of authorized policy creation
* Thu Jul 20 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.6
  + Avoid cleaning the temp directory when calling tpm_test
  + firstboot/fde: use functions as the aliases for bootloader
    functions
  + firstboot/fde: always regenerate initrd
  + firstboot/fde: use authorized policy by default
  + Support devices other than the root partition
- Drop upstreamed patches
  + fde-tools-avoid-cleaning-temp-dir.patch
  + fde-tools-fix-bootloader-func.patch
  + fde-tools-force-dracut.patch
  + fde-tools-enable-authpol-in-firstboot.patch
* Thu Jul 13 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-enable-authpol-in-firstboot.patch to enable
  authorized policy in the firstboot script
* Fri Jul  7 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-fix-bootloader-func.patch
  + Define the bootloader specific functions in the firstboot
    script since the aliases are not expanded
- Add fde-tools-force-dracut.patch
  + Always regenerate initrd
* Tue Jul  4 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-avoid-cleaning-temp-dir.patch to avoid cleaning
  the temp directory when calling tpm_test
* Tue Jul  4 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.5
  + LUKS2 keyslot management with the grub-tpm2 token
  + Replace mkinitrd with dracut
* Wed Jun 14 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 0.6.4
  + Add man page and bash completion support
  + Switch to TPM 2.0 Key File for grub2
  + Update the installation paths
  + Enable authorized policy by default
  + Implement 'tpm-disable' command (bsc#1208834)
- Add a subpackage: fde-tools-bash-completion
- Use 'tpm-activate' in the systemd service file
- Add help2man to BuildRequires
- Drop the upstreamed patches
  + fde-tools-tpm2.0-key-file-support.patch
  + fde-tools-fix-paths.patch
  + fde-tools-set-stop-event-for-tpm_authorize.patch
  + fde-tools-enable-authorized-policy-by-default.patch
  + fde-tools-reduce-iterations.patch
  + fde-tools-set-grub.cfg-as-stop-event.patch
* Thu Jun  8 2023 Gary Ching-Pang Lin <glin@suse.com>
- Fix the path in fde-tools.service
* Wed Jun  7 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-tpm2.0-key-file-support.patch to support TPM 2.0
  Key File for grub2
- Bump the required pcr-oracle version to 0.4.5 for the TPM 2.0 Key
  File support
- Add fde-tools-reduce-iterations.patch to reduce the iterations
  for the key created by luks_add_random_key
- Add fde-tools-set-grub.cfg-as-stop-event.patch to set grub.cfg as
  the stop event for the PCR prediction
- Add fde-tools-enable-authorized-policy-by-default.patch to switch
  FDE_USE_AUTHORIZED_POLICIES to yes
* Tue Jun  6 2023 Marcus Meissner <meissner@suse.com>
- remove dracut and jeos-firstboot from buildrequires, just specify
  the directory.
* Wed May 17 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-fix-paths.patch to fix the installation paths
- Using the tarball from the github repo
- Remove %%clean
* Fri Apr 21 2023 Gary Ching-Pang Lin <glin@suse.com>
- Update project URL
* Tue Mar 28 2023 Gary Ching-Pang Lin <glin@suse.com>
- Apply fde-tools-set-stop-event-for-tpm_authorize.patch correctly
* Mon Mar  6 2023 Gary Ching-Pang Lin <glin@suse.com>
- Add fde-tools-set-stop-event-for-tpm_authorize.patch to set the
  stop event when signing the authorized policy
* Wed Mar  1 2023 Olaf Kirch <okir@suse.com>
- firstboot/fde: ensure that aliases get expanded in shell scripts
  This is needed to make the bootloader_foo -> grub2_foo function
  name expansion work
* Tue Feb 28 2023 Olaf Kirch <okir@suse.com>
- Updated to version 0.6.3
- Fix a bug introduced by the recent change in tempdir handling
* Mon Jan  9 2023 Olaf Kirch <okir@suse.com>
- Updated to version 0.6.2
- Several patches that were added last-minute for the December
  snapshot have been folded back into git.
- Implement first stab at authorized policies.
* Wed Dec 14 2022 Olaf Kirch <okir@suse.com>
- Fix several bugs in firstboot
  * The approach for reading the initial FDE pass phrase
    from /etc/default/grub is not supported in kiwi yet,
    so work around that
  * The kiwi KVM images have a strange EFI boot path that
    does not contain a File component. Try to work
    around that.
  * shim-install behaves differently between kiwi image build time
    and the installed system. Work around.
* Tue Dec 13 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Fix source URL
* Tue Dec 13 2022 Olaf Kirch <okir@suse.com>
- Fix the fde-tpm-enroll.service file
* Mon Dec 12 2022 Olaf Kirch <okir@suse.com>
- Updated to version 0.6.1
- Fix tpm-enable subcommand
- Add new add-secondary-key subcommand
- Add a systemd unit file that triggers on the presence of the
  key file written by d-installer
* Wed Dec  7 2022 Olaf Kirch <okir@suse.com>
- Updated to version 0.6
- pcr-oracle is now a standalone project and package
- Split off the jeos-firstboot stuff into a binary package of its own,
  because bare metal installations do not need it
- Refactoring the scripts
- Folded Gary's patches into git.
* Fri Oct 14 2022 Gary Ching-Pang Lin <glin@suse.com>
- Add bsc1204037-mokutil-check-sb-state.patch to check the
  SecureBoot state with mokutil (bsc#1204037)
* Thu Oct 13 2022 Gary Ching-Pang Lin <glin@suse.com>
- Add bsc1204037-update-grub.cfg-for-pw-only.patch to update
  grub.cfg when the user only chooses the pass phrase to encrypt
  the disk. (bsc#1204037)
* Fri Sep 30 2022 Dirk Müller <dmueller@suse.com>
- add build support for other architectures
- spec file clean ups
* Fri Sep 16 2022 Olaf Kirch <okir@suse.com>
- Move the (shipped) keyfile into /root to avoid issues with r/o root
* Tue Sep 13 2022 Olaf Kirch <okir@suse.com>
- Introduce a specific unit script that takes care of mounting root
  early (to avoid conflicts with ignition).
* Mon Aug 29 2022 Olaf Kirch <okir@suse.com>
- Make the firstboot workflow smarter (offer different key protectors)
* Mon Aug 15 2022 Olaf Kirch <okir@suse.com>
- Fixed typo of tpm2_key_protector_clear
* Mon Aug 15 2022 Olaf Kirch <okir@suse.com>
- Renamed to fde-tools-0.1
- included firstboot stuff
* Tue Jul 26 2022 Olaf Kirch <okir@suse.com>
- Initial build as package pcr-oracle
